@@ -267,7 +267,8 @@ class AddUpdateEntryForm(forms.ModelForm):
 
     class Meta:
         model = Entry
-        exclude = ('user', 'pause_time', 'site', 'hours', 'status',)
+        exclude = ('user', 'pause_time', 'site', 'hours', 'status',
+                   'entry_group')
 
     def __init__(self, *args, **kwargs):
         self.user = kwargs.pop('user')
@@ -291,9 +292,6 @@ class AddUpdateEntryForm(forms.ModelForm):
         if not start:
             raise forms.ValidationError(
                 'Please enter a valid date/time.')
-        if start >= datetime.now() or end and end > datetime.now():
-            raise forms.ValidationError(
-                'Entries may not be added in the future.')
         #Obtain all current entries, except the one being edited
         times = [start, end] if end else [start]
         query = reduce(lambda q, time: q | Q(start_time__lte=time), times, Q())
@@ -334,6 +332,15 @@ class DateForm(forms.Form):
         widget=forms.HiddenInput(), required=False,
     )
 
+    def clean(self):
+        data = self.cleaned_data
+        from_date = data.get('from_date', None)
+        to_date = data.get('to_date', None)
+        if from_date and to_date and from_date > to_date:
+            err_msg = 'The ending date must exceed the beginning date'
+            raise ValidationError(err_msg)
+        return data
+
     def save(self):
         from_date = self.cleaned_data.get('from_date', '')
         to_date = self.cleaned_data.get('to_date', '')
@@ -361,6 +368,10 @@ class YearMonthForm(forms.Form):
             first_year = first_entry.end_time.year
         years = [(year, year) for year in xrange(first_year, this_year + 1)]
         self.fields['year'].choices = years
+        initial = kwargs.get('initial')
+        if initial:
+            this_year = initial.get('year', this_year)
+            this_month = initial.get('month', this_month)
         self.fields['year'].initial = this_year
         self.fields['month'].initial = this_month
 
@@ -400,6 +411,7 @@ class ProjectForm(forms.ModelForm):
             'point_person',
             'type',
             'status',
+            'activity_group',
             'description',
         )
 
@@ -425,6 +437,23 @@ class ProjectRelationshipForm(forms.ModelForm):
         self.fields['types'].help_text = ''
 
 
+class InvoiceForm(forms.ModelForm):
+    class Meta:
+        model = timepiece.EntryGroup
+        fields = ('status', 'number', 'comments')
+
+    def save(self, commit=True):
+        instance = super(InvoiceForm, self).save(commit=False)
+        instance.project = self.initial['project']
+        instance.user = self.initial['user']
+        from_date = self.initial['from_date']
+        to_date = self.initial['to_date']
+        instance.start = from_date
+        instance.end = to_date
+        instance.save()
+        return instance
+
+
 class RepeatPeriodForm(forms.ModelForm):
     class Meta:
         model = timepiece.RepeatPeriod
