@@ -185,6 +185,49 @@ class Activity(models.Model):
         verbose_name_plural = 'activities'
 
 
+class HourGroupManager(models.Manager):
+    def summaries(self, entries):
+        #Get the list of bundle names and hour sums
+        bundled_entries = entries.values('activity__activity_bundle',
+                                         'activity__activity_bundle__name')
+        bundled_entries = bundled_entries.annotate(Sum('hours'))
+        bundled_entries = bundled_entries.order_by(
+                                            'activity__activity_bundle__order',
+                                            'activity__activity_bundle__name'
+        )
+        bundled_totals = list(bundled_entries.values_list(
+                                             'activity__activity_bundle__name',
+                                             'activity__activity_bundle',
+                                             'hours__sum')
+        )
+        #Get the list of activity names and hour sums
+        activity_entries = entries.values('activity', 'activity__name', 
+                                          'activity__activity_bundle')
+        activity_entries = activity_entries.annotate(Sum('hours'))
+        activity_entries = activity_entries.order_by('activity')
+        activity_totals = list(activity_entries.values_list(
+                                                   'activity__name',
+                                                   'activity__activity_bundle',
+                                                   'hours__sum')
+        )
+        totals = {}
+        other_values = ()
+        for bundle in bundled_totals:
+            bundle_key, bundle_value = bundle[0], bundle[2]
+            act_values = [(act[0], act[2]) for act in activity_totals \
+                          if act[1] == bundle[1]]
+            if bundle_key is not None:
+                totals[bundle_key] = (bundle_value, act_values)
+            else:
+                other_values = (bundle_value, act_values)
+        totals = sorted(totals.items())
+        if other_values:
+            totals.append(('Other', other_values))
+        all_totals = sum([bt[2] for bt in bundled_totals])
+        totals.append(('Total', (all_totals, [])))
+        return totals
+
+
 class HourGroup(models.Model):
     """Activities that are bundled together for billing"""
 
@@ -195,6 +238,8 @@ class HourGroup(models.Model):
     )
     order = models.PositiveIntegerField(unique=True, blank=True, null=True)
 
+    objects = HourGroupManager()
+
     def __unicode__(self):
         return self.name
 
@@ -573,7 +618,8 @@ class EntryGroup(models.Model):
     project = models.ForeignKey(Project, related_name='entry_group')
     status = models.CharField(max_length=24, choices=STATUS_CHOICES,
                               default='invoiced')
-    number = models.IntegerField("Reference #", blank=True, null=True)
+    number = models.CharField("Reference #", max_length=50, blank=True,
+                              null=True)
     comments = models.TextField(blank=True, null=True)
     created = models.DateTimeField(auto_now_add=True)
     modified = models.DateTimeField(auto_now=True)
@@ -591,8 +637,8 @@ class EntryGroup(models.Model):
             'project': self.project,
             'end': self.end.strftime('%b %Y'),
         }
-        return 'Entry Group ' + \
-               '%(number)s: %(status)s - %(project)s - %(end)s' % invoice_data
+        return u'Entry Group ' + \
+               u'%(number)s: %(status)s - %(project)s - %(end)s' % invoice_data
 
 
 # Add a utility method to the User class that will tell whether or not a
