@@ -163,12 +163,17 @@ urlpatterns = patterns('',
     url(
         r'^invoice/(?P<pk>\d+)/$',
         views.InvoiceDetail.as_view(),
-        name='view_invoice'
+        name='view_invoice',
+    ),
+    url(
+        r'^invoice/(?P<pk>\d+)/entries/$',
+        views.InvoiceEntryDetail.as_view(),
+        name='view_invoice_entries',
     ),
     url(
         r'^invoice/(?P<pk>\d+)/csv/$',
         views.InvoiceCSV.as_view(),
-        name='view_invoice_csv'
+        name='view_invoice_csv',
     ),
     url(
         r'^invoice/edit/(?P<pk>\d+)/$',
@@ -185,9 +190,15 @@ urlpatterns = patterns('',
         views.remove_invoice_entry,
         name='remove_invoice_entry',
     ),
+    # contracts
     url(
         r'^contract/(?P<pk>\d+)/$',
         views.ContractDetail.as_view(),
         name='view_contract',
     ),
+    url(
+        r'^contract/list/$',
+        views.ContractList.as_view(),
+        name='list_contracts',
+    ),
 )
