@@ -674,7 +674,7 @@ def confirm_invoice_project(request, project_id, to_date, from_date=None):
     }
     entries_query = {
         'status': "approved",
-        'end_time__lt': to_date,
+        'end_time__lt': to_date + relativedelta(days=1),
         'project__id': project.id
     }
     if from_date:
@@ -692,7 +692,7 @@ def confirm_invoice_project(request, project_id, to_date, from_date=None):
         if not entries:
             raise Http404
 
-    totals = utils.hour_group_totals(entries)
+    totals = timepiece.HourGroup.objects.summaries(entries)
     template = 'timepiece/time-sheet/invoice/confirm.html'
     return render_to_response(template, {
         'invoice_form': invoice_form,
@@ -718,12 +718,6 @@ def invoice_projects(request):
     datesQ &= Q(end_time__gte=from_date)  if from_date else Q()
     datesQ &= Q(end_time__lt=to_date)  if to_date else Q()
     entries = timepiece.Entry.objects.filter(datesQ)
-
-    user_values = ['user__pk', 'user__first_name', 'user__last_name']
-    unverified = entries.filter(status='unverified', user__is_active=True)
-    unverified = unverified.values_list(*user_values).distinct()
-    unapproved = entries.filter(status='verified')
-    unapproved = unapproved.values_list(*user_values).distinct()
     project_totals = entries.filter(status='approved',
         project__type__billable=True, project__status__billable=True).values(
         'project__type__pk', 'project__type__label', 'project__name', 'hours',
@@ -736,8 +730,6 @@ def invoice_projects(request):
         'project_totals': project_totals if to_date else [],
         'to_date': to_date - relativedelta(days=1) if to_date else '',
         'from_date': from_date,
-        'unverified': unverified,
-        'unapproved': unapproved,
     }, context_instance=RequestContext(request))
 
 
@@ -764,15 +756,25 @@ class InvoiceDetail(DetailView):
         context = super(InvoiceDetail, self).get_context_data(**kwargs)
         invoice = context['invoice']
         entries = invoice.entries.order_by('start_time').select_related()
-        context = {
+        return {
             'invoice': invoice,
+            'entries': entries,
+            'totals': timepiece.HourGroup.objects.summaries(entries),
             'from_date': invoice.start,
             'to_date': invoice.end,
             'project': invoice.project,
-            'entries': entries,
-            'totals': utils.hour_group_totals(entries),
-            'total': entries.aggregate(hours=Sum('hours'))['hours'],
         }
+
+
+class InvoiceEntryDetail(InvoiceDetail):
+    template_name = 'timepiece/time-sheet/invoice/view_entries.html'
+
+    def get_context_data(self, **kwargs):
+        context = super(InvoiceEntryDetail, self).get_context_data(**kwargs)
+        entries = context['entries']
+        context.update({
+            'total': entries.aggregate(hours=Sum('hours'))['hours'],
+        })
         return context
 
 
@@ -808,7 +810,8 @@ class InvoiceCSV(CSVMixin, InvoiceDetail):
                 entry.hours,
             ]
             rows.append(data)
-        rows.append(('', '', '', '', '', '', 'Total:', context['total']))
+        total = context['entries'].aggregate(hours=Sum('hours'))['hours']
+        rows.append(('', '', '', '', '', '', 'Total:', total))
         return rows
 
 
@@ -1299,31 +1302,38 @@ def payroll_summary(request):
         to_date = from_date + relativedelta(months=1)
     last_billable = utils.get_last_billable_day(from_date)
     projects = getattr(settings, 'TIMEPIECE_PROJECTS', {})
-    workQ = ~Q(project__in=projects.values())
     weekQ = Q(end_time__gt=utils.get_week_start(from_date),
               end_time__lt=last_billable + datetime.timedelta(days=1))
     monthQ = Q(end_time__gt=from_date, end_time__lt=to_date)
+    workQ = ~Q(project__in=projects.values())
     statusQ = Q(status='invoiced') | Q(status='approved')
-    weekQ &= statusQ
-    monthQ &= statusQ
-    #Weekly totals
-    entries = timepiece.Entry.objects.date_trunc('week').filter(weekQ, workQ)
+    # Weekly totals
+    week_entries = timepiece.Entry.objects.date_trunc('week')
+    week_entries = week_entries.filter(weekQ, statusQ, workQ)
     date_headers = utils.generate_dates(from_date, last_billable, by='week')
-    weekly_totals = list(utils.project_totals(entries, date_headers, 'total',
-                                              overtime=True))
-    #Monthly totals
+    weekly_totals = list(utils.project_totals(week_entries, date_headers,
+                                              'total', overtime=True))
+    # Monthly totals
     leave = timepiece.Entry.objects.filter(monthQ, ~workQ
                                   ).values('user', 'hours', 'project__name')
-    month_entries = timepiece.Entry.objects.date_trunc('month').filter(monthQ,
-                                                                       workQ)
-    monthly_totals = list(utils.payroll_totals(month_entries, from_date,
+    month_entries = timepiece.Entry.objects.date_trunc('month')
+    month_entries_valid = month_entries.filter(monthQ, statusQ, workQ)
+    monthly_totals = list(utils.payroll_totals(month_entries_valid, from_date,
                                                leave))
+    # Unapproved and unverified hours
+    entries = timepiece.Entry.objects.filter(monthQ)
+    user_values = ['user__pk', 'user__first_name', 'user__last_name']
+    unverified =  entries.filter(monthQ, status='unverified',
+                                 user__is_active=True)
+    unapproved = entries.filter(monthQ, status='verified')
     return {
         'from_date': from_date,
         'year_month_form': year_month_form,
         'date_headers': date_headers,
         'weekly_totals': weekly_totals,
         'monthly_totals': monthly_totals,
+        'unverified': unverified.values_list(*user_values).distinct(),
+        'unapproved': unapproved.values_list(*user_values).distinct(),
     }
 
 
@@ -1406,8 +1416,8 @@ def hourly_report(request, date_form, from_date, to_date, status, activity):
     hour_type = form.get_hour_type()
     entries = timepiece.Entry.objects.date_trunc(trunc).filter(query)
     date_headers = utils.generate_dates(from_date, header_to, by=trunc)
-    project_totals = utils.project_totals(entries, date_headers, hour_type) \
-        if entries else ''
+    project_totals = utils.project_totals(entries, date_headers, hour_type,
+                                          total_column=True) if entries else ''
     if not request.GET.get('export', False):
         return {
             'date_form': date_form,
@@ -1427,6 +1437,7 @@ def hourly_report(request, date_form, from_date, to_date, status, activity):
         writer = csv.writer(response)
         headers = ['Name']
         headers.extend([date.strftime('%m/%d/%Y') for date in date_headers])
+        headers.append('Total')
         writer.writerow(headers)
         for rows, totals in project_totals:
             for name, hours in rows:
@@ -1444,6 +1455,23 @@ class ContractDetail(DetailView):
     model = timepiece.ProjectContract
     context_object_name = 'contract'
 
-    @method_decorator(permission_required('timepiece.add_entry'))
+    @method_decorator(permission_required('timepiece.add_project_contract'))
     def dispatch(self, *args, **kwargs):
         return super(ContractDetail, self).dispatch(*args, **kwargs)
+
+
+class ContractList(ListView):
+    template_name = 'timepiece/time-sheet/contract/list.html'
+    model = timepiece.ProjectContract
+    context_object_name = 'contracts'
+    queryset = timepiece.ProjectContract.objects.filter(
+        status='current'
+    ).select_related(
+        'project'
+    ).order_by(
+        'project__name'
+    )
+
+    @method_decorator(permission_required('timepiece.add_project_contract'))
+    def dispatch(self, *args, **kwargs):
+        return super(ContractList, self).dispatch(*args, **kwargs)
